@@ -1,5 +1,13 @@
 package Inline::CPP;
 
+#============================================================================
+# Editing Best practices:
+#     Unix line endings.
+#     Four spaces for indentation (no tabs).
+#     Conditional modifiers go on the following line, indented four spaces.
+#     Others as issues reveal themselves.
+#============================================================================
+
 use strict;
 require Inline::C;
 require Inline::CPP::grammar;
@@ -8,7 +16,7 @@ use Carp;
 use vars qw(@ISA $VERSION);
 
 @ISA = qw(Inline::C);
-$VERSION = '0.29';
+$VERSION = '0.30';
 my $TYPEMAP_KIND = $Inline::CPP::grammar::TYPEMAP_KIND;
 
 #============================================================================
@@ -17,11 +25,11 @@ my $TYPEMAP_KIND = $Inline::CPP::grammar::TYPEMAP_KIND;
 sub register {
     use Config;
     return {
-	    language => 'CPP',
-	    aliases => ['cpp', 'C++', 'c++', 'Cplusplus', 'cplusplus', 'CXX', 'cxx'],
-	    type => 'compiled',
-	    suffix => $Config{dlext},
-	   };
+        language => 'CPP',
+        aliases => ['cpp', 'C++', 'c++', 'Cplusplus', 'cplusplus', 'CXX', 'cxx'],
+        type => 'compiled',
+        suffix => $Config{dlext},
+       };
 }
 
 #============================================================================
@@ -29,17 +37,17 @@ sub register {
 #============================================================================
 sub validate {
     my $o = shift;
-    $o->{ILSM}{MAKEFILE}{CC} ||= 'g++'; # default compiler
-    $o->{ILSM}{MAKEFILE}{LIBS} ||= ['-lstdc++']; # default libs
+ $o->{ILSM}{MAKEFILE}{CC} ||= 'g++'; # default compiler
+ $o->{ILSM}{MAKEFILE}{LIBS} ||= ['-lstdc++']; # default libs
 
     # I haven't traced it out yet, but $o->{STRUCT} gets set before getting
     # properly set from Inline::C's validate().
     $o->{STRUCT} ||= {
-		      '.macros' => '',
-		      '.xs' => '',
-		      '.any' => 0, 
-		      '.all' => 0,
-		     };
+              '.macros' => '',
+              '.xs' => '',
+              '.any' => 0, 
+              '.all' => 0,
+             };
     $o->{ILSM}{AUTO_INCLUDE} ||= <<END;
 #ifndef bool
 #include <%iostream%>
@@ -62,35 +70,39 @@ END
     # Filter out the parameters we treat differently than Inline::C
     my @propagate;
     while(@_) {
-	my ($key, $value) = (shift, shift);
-	if ($key eq 'LIBS') {
-	    $value = [$value] unless ref $value eq 'ARRAY';
-	    my $num = scalar @{$o->{ILSM}{MAKEFILE}{LIBS}} - 1;
-	    $o->{ILSM}{MAKEFILE}{LIBS}[$num] .= ' ' . $_
-	      for (@$value);
-	    next;
-	}
-	if ($key eq 'ALTLIBS') {
-	    $value = [$value] unless ref $value eq 'ARRAY';
-	    push @{$o->{ILSM}{MAKEFILE}{LIBS}}, '';
-	    my $num = scalar @{$o->{ILSM}{MAKEFILE}{LIBS}} - 1;
-	    $o->{ILSM}{MAKEFILE}{LIBS}[$num] .= ' ' . $_
-	      for (@$value);
-	    next;
-	}
-	if ($key eq 'PRESERVE_ELLIPSIS' or 
-	    $key eq 'STD_IOSTREAM') {
-	    croak "Argument to $key must be 0 or 1" 
-	      unless $value == 0 or $value == 1;
-	    $o->{ILSM}{$key} = $value;
-	    next;
-	}
-	push @propagate, $key, $value;
+    my ($key, $value) = (shift, shift);
+    if ($key eq 'LIBS') {
+        $value = [$value] unless ref $value eq 'ARRAY';
+        my $num = scalar @{$o->{ILSM}{MAKEFILE}{LIBS}} - 1;
+        $o->{ILSM}{MAKEFILE}{LIBS}[$num] .= ' ' . $_
+          for (@$value);
+        next;
+    }
+    if ($key eq 'ALTLIBS') {
+        $value = [$value] unless ref $value eq 'ARRAY';
+        push @{$o->{ILSM}{MAKEFILE}{LIBS}}, '';
+        my $num = scalar @{$o->{ILSM}{MAKEFILE}{LIBS}} - 1;
+        $o->{ILSM}{MAKEFILE}{LIBS}[$num] .= ' ' . $_
+          for (@$value);
+        next;
+    }
+    if ($key eq 'PRESERVE_ELLIPSIS' or 
+        $key eq 'STD_IOSTREAM') {
+        croak "Argument to $key must be 0 or 1" 
+          unless $value == 0 or $value == 1;
+        $o->{ILSM}{$key} = $value;
+        next;
+    }
+    push @propagate, $key, $value;
     }
 
     # Replace %iostream% with the correct iostream library
     my $iostream = "iostream";
 #    $iostream .= ".h" unless $o->{ILSM}{STD_IOSTREAM};
+    if($o->{ILSM}{MAKEFILE}{CC} =~ /^cl/) { 
+        $iostream .= ".h" 
+            unless $o->{ILSM}{STD_IOSTREAM}; 
+    }
     $o->{ILSM}{AUTO_INCLUDE} =~ s|%iostream%|$iostream|g;
 
     # Forward all unknown requests up to Inline::C
@@ -109,58 +121,58 @@ sub info {
 
     my (@class, @func);
     if (defined $data->{classes}) {
-	for my $class (sort @{$data->{classes}}) {
-	    my @parents = grep { $_->{thing} eq 'inherits' }
-	      @{$data->{class}{$class}};
-	    push @class, "\tclass $class";
-	    push @class, (" : " 
-		      . join (', ', 
-			      map { $_->{scope} . " " . $_->{name} } @parents)
-		     ) if @parents;
-	    push @class, " {\n";
-	    for my $thing (sort { $a->{name} cmp $b->{name} } 
-			   @{$data->{class}{$class}}) {
-		my ($name, $scope, $type) = @{$thing}{qw(name scope thing)};
-		next unless $scope eq 'public' and $type eq 'method';
-		next unless $o->check_type(
-		    $thing,
-		    $name eq $class,
-		    $name eq "~$class",
-		);
-		my $rtype = $thing->{rtype} || "";
-		push @class, "\t\t$rtype" . ($rtype ? " " : "");
-		push @class, $class . "::$name(";
-		my @args = grep { $_->{name} ne '...' } @{$thing->{args}};
-		my $ellipsis = (scalar @{$thing->{args}} - scalar @args) != 0;
-		push @class, join ', ', (map "$_->{type} $_->{name}", @args), 
-		  $ellipsis ? "..." : ();
-		push @class, ");\n";
-	    }
-	    push @class, "\t};\n"
-	}
+    for my $class (sort @{$data->{classes}}) {
+        my @parents = grep { $_->{thing} eq 'inherits' }
+          @{$data->{class}{$class}};
+        push @class, "\tclass $class";
+        push @class, (" : " 
+              . join (', ', 
+                  map { $_->{scope} . " " . $_->{name} } @parents)
+             ) if @parents;
+        push @class, " {\n";
+        for my $thing (sort { $a->{name} cmp $b->{name} } 
+               @{$data->{class}{$class}}) {
+        my ($name, $scope, $type) = @{$thing}{qw(name scope thing)};
+        next unless $scope eq 'public' and $type eq 'method';
+        next unless $o->check_type(
+            $thing,
+            $name eq $class,
+            $name eq "~$class",
+        );
+        my $rtype = $thing->{rtype} || "";
+        push @class, "\t\t$rtype" . ($rtype ? " " : "");
+        push @class, $class . "::$name(";
+        my @args = grep { $_->{name} ne '...' } @{$thing->{args}};
+        my $ellipsis = (scalar @{$thing->{args}} - scalar @args) != 0;
+        push @class, join ', ', (map "$_->{type} $_->{name}", @args), 
+          $ellipsis ? "..." : ();
+        push @class, ");\n";
+        }
+        push @class, "\t};\n"
+    }
     }
     if (defined $data->{functions}) {
-	for my $function (sort @{$data->{functions}}) {
-	    my $func = $data->{function}{$function};
-	    next if $function =~ /::/;
-	    next unless $o->check_type($func, 0, 0);
-	    push @func, "\t" . $func->{rtype} . " ";
-	    push @func, $func->{name} . "(";
-	    my @args = grep { $_->{name} ne '...' } @{$func->{args}};
-	    my $ellipsis = (scalar @{$func->{args}} - scalar @args) != 0;
-	    push @func, join ', ', (map "$_->{type} $_->{name}", @args), 
-	      $ellipsis ? "..." : ();
-	    push @func, ");\n";
-	}
+    for my $function (sort @{$data->{functions}}) {
+        my $func = $data->{function}{$function};
+        next if $function =~ /::/;
+        next unless $o->check_type($func, 0, 0);
+        push @func, "\t" . $func->{rtype} . " ";
+        push @func, $func->{name} . "(";
+        my @args = grep { $_->{name} ne '...' } @{$func->{args}};
+        my $ellipsis = (scalar @{$func->{args}} - scalar @args) != 0;
+        push @func, join ', ', (map "$_->{type} $_->{name}", @args), 
+          $ellipsis ? "..." : ();
+        push @func, ");\n";
+    }
     }
 
     # Report:
     {
-	local $" = '';
-	$info .= "The following classes have been bound to Perl:\n@class\n"
-	    if @class;
-	$info .= "The following functions have been bound to Perl:\n@func\n"
-	    if @func;
+    local $" = '';
+    $info .= "The following classes have been bound to Perl:\n@class\n"
+        if @class;
+    $info .= "The following functions have been bound to Perl:\n@func\n"
+        if @func;
     }
     $info .= Inline::Struct::info($o) if $o->{STRUCT}{'.any'};
     return $info;
@@ -172,7 +184,7 @@ sub info {
 sub get_parser {
     my $o = shift;
     my $grammar = Inline::CPP::grammar::grammar()
-	or croak "Can't find C++ grammar\n";
+    or croak "Can't find C++ grammar\n";
     $::RD_HINT++;
     require Parse::RecDescent;
     my $parser = Parse::RecDescent->new($grammar);
@@ -200,32 +212,32 @@ sub xs_bindings {
     my @XS;
 
     warn("Warning: No Inline C++ functions or classes bound to Perl\n" .
-	 "Check your C++ for Inline compatibility.\n\n")
+     "Check your C++ for Inline compatibility.\n\n")
       if ((not defined $data->{classes}) 
-	  and (not defined $data->{functions})
-	  and ($^W));
+      and (not defined $data->{functions})
+      and ($^W));
 
     for my $class (@{$data->{classes}}) {
-	my $proper_pkg = $pkg . "::$class";
-	# Set up the proper namespace
-	push @XS, <<END;
+    my $proper_pkg = $pkg . "::$class";
+    # Set up the proper namespace
+    push @XS, <<END;
 
-MODULE = $module     	PACKAGE = $proper_pkg
+MODULE = $module        PACKAGE = $proper_pkg
 
 PROTOTYPES: DISABLE
 
 END
 
-	my ($ctor, $dtor, $abstract) = (0, 0, 0);
-	for my $thing (@{$data->{class}{$class}}) {
-	    my ($name, $scope, $type) = @{$thing}{qw|name scope thing|};
+    my ($ctor, $dtor, $abstract) = (0, 0, 0);
+    for my $thing (@{$data->{class}{$class}}) {
+        my ($name, $scope, $type) = @{$thing}{qw|name scope thing|};
 
-	    # Let Perl handle inheritance
-	    if ($type eq 'inherits' and $scope eq 'public') {
-		$o->{ILSM}{XS}{BOOT} ||= '';
-		my $ISA_name = "${pkg}::${class}::ISA";
-		my $parent = "${pkg}::${name}";
-		$o->{ILSM}{XS}{BOOT} .= <<END;
+        # Let Perl handle inheritance
+        if ($type eq 'inherits' and $scope eq 'public') {
+        $o->{ILSM}{XS}{BOOT} ||= '';
+        my $ISA_name = "${pkg}::${class}::ISA";
+        my $parent = "${pkg}::${name}";
+        $o->{ILSM}{XS}{BOOT} .= <<END;
 {
 #ifndef get_av
     AV *isa = perl_get_av("$ISA_name", 1);
@@ -235,33 +247,33 @@ END
     av_push(isa, newSVpv("$parent", 0));
 }
 END
-	    }
+        }
 
-	    # Get/set methods will go here:
+        # Get/set methods will go here:
 
-	    # Cases we skip:
-	    $abstract ||= ($type eq 'method' and $thing->{abstract});
-	    next if ($type eq 'method' and $thing->{abstract});
-	    next if $scope ne 'public';
-	    if ($type eq 'enum') {
-		$o->{ILSM}{XS}{BOOT} .= make_enum($proper_pkg, $name,
-						  $thing->{body});
-	    } elsif ($type eq 'method') {
-		next if $name =~ /operator/;
-		# generate an XS wrapper
-		$ctor ||= ($name eq $class);
-		$dtor ||= ($name eq "~$class");
-		push @XS, $o->wrap($thing, $name, $class);
-	    }
-	}
+        # Cases we skip:
+        $abstract ||= ($type eq 'method' and $thing->{abstract});
+        next if ($type eq 'method' and $thing->{abstract});
+        next if $scope ne 'public';
+        if ($type eq 'enum') {
+        $o->{ILSM}{XS}{BOOT} .= make_enum($proper_pkg, $name,
+                          $thing->{body});
+        } elsif ($type eq 'method') {
+        next if $name =~ /operator/;
+        # generate an XS wrapper
+        $ctor ||= ($name eq $class);
+        $dtor ||= ($name eq "~$class");
+        push @XS, $o->wrap($thing, $name, $class);
+        }
+    }
 
-	# Provide default constructor and destructor:
-	push @XS, <<END unless ($ctor or $abstract);
+    # Provide default constructor and destructor:
+    push @XS, <<END unless ($ctor or $abstract);
 $class *
 ${class}::new()
 
 END
-	push @XS, <<END unless ($dtor or $abstract);
+    push @XS, <<END unless ($dtor or $abstract);
 void
 ${class}::DESTROY()
 
@@ -269,29 +281,29 @@ END
     }
 
     my $prefix = (
-	$o->{ILSM}{XS}{PREFIX}
-	? "PREFIX = $o->{ILSM}{XS}{PREFIX}"
-	: ''
+    $o->{ILSM}{XS}{PREFIX}
+    ? "PREFIX = $o->{ILSM}{XS}{PREFIX}"
+    : ''
     );
     push @XS, <<END;
-MODULE = $module     	PACKAGE = $pkg	$prefix
+MODULE = $module        PACKAGE = $pkg  $prefix
 
 PROTOTYPES: DISABLE
 
 END
 
     for my $function (@{$data->{functions}}) {
-	# lose constructor defs outside class decls (and "implicit int")
-	next if $data->{function}{$function}{rtype} eq '';
-	next if $data->{function}{$function}{rtype} =~ 'static'; # special case
-	next if $function =~ /::/; # XXX: skip member functions?
-	next if $function =~ /operator/; # and operators.
-	push @XS, $o->wrap($data->{function}{$function}, $function);
+    # lose constructor defs outside class decls (and "implicit int")
+    next if $data->{function}{$function}{rtype} eq '';
+    next if $data->{function}{$function}{rtype} =~ 'static'; # special case
+    next if $function =~ /::/; # XXX: skip member functions?
+    next if $function =~ /operator/; # and operators.
+    push @XS, $o->wrap($data->{function}{$function}, $function);
     }
 
     for (@{$data->{enums}}) {
-	# Global enums.
-	$o->{ILSM}{XS}{BOOT} .= make_enum($pkg, @$_{qw(name body)});
+    # Global enums.
+    $o->{ILSM}{XS}{BOOT} .= make_enum($pkg, @$_{qw(name body)});
     }
 #     print "BOOT = \n", $o->{ILSM}{XS}{BOOT};
 
@@ -311,19 +323,19 @@ sub wrap {
     my (@XS, @PREINIT, @CODE);
     my ($ctor, $dtor) = (0, 0);
 
-    if ($name eq $class) { 	# ctor
-	push @XS, $class . " *\n" . $class . "::new";
-	$ctor = 1;
+    if ($name eq $class) {  # ctor
+    push @XS, $class . " *\n" . $class . "::new";
+    $ctor = 1;
     }
     elsif ($name eq "~$class") { # dtor
-	push @XS, "void\n$class" . "::DESTROY";
-	$dtor = 1;
+    push @XS, "void\n$class" . "::DESTROY";
+    $dtor = 1;
     }
-    elsif ($class) {		# method
-	push @XS, "$thing->{rtype}\n$class" . "::$thing->{name}";
+    elsif ($class) {        # method
+    push @XS, "$thing->{rtype}\n$class" . "::$thing->{name}";
     }
-    else {			# function
-	push @XS, "$thing->{rtype}\n$thing->{name}";
+    else {          # function
+    push @XS, "$thing->{rtype}\n$thing->{name}";
     }
 
     return '' unless $o->check_type($thing, $ctor, $dtor);
@@ -334,13 +346,13 @@ sub wrap {
     $ellipsis = pop @args if (@args and $args[-1]{name} eq '...');
     $void = ($thing->{rtype} and $thing->{rtype} eq 'void');
     push @XS, join '', (
-	"(",
-	join(
-	    ", ",
-	    (map {$_->{name}} @args),
-	    (scalar @opts or $ellipsis) ? '...' : ()
-	),
-	")\n",
+    "(",
+    join(
+        ", ",
+        (map {$_->{name}} @args),
+        (scalar @opts or $ellipsis) ? '...' : ()
+    ),
+    ")\n",
     );
 
     # Declare the non-optional arguments for XS type-checking
@@ -348,58 +360,58 @@ sub wrap {
 
     # Wrap "complicated" subs in stack-checking code
     if ($void or $ellipsis) {
-	push @PREINIT, "\tI32 *\t__temp_markstack_ptr;\n";
-	push @CODE, "\t__temp_markstack_ptr = PL_markstack_ptr++;\n";
+    push @PREINIT, "\tI32 *\t__temp_markstack_ptr;\n";
+    push @CODE, "\t__temp_markstack_ptr = PL_markstack_ptr++;\n";
     }
 
     if (@opts) {
-	push @PREINIT, "\t$_->{type}\t$_->{name};\n" for @opts;
-	push @CODE, "switch(items" . ($class ? '-1' : '') . ") {\n";
+    push @PREINIT, "\t$_->{type}\t$_->{name};\n" for @opts;
+    push @CODE, "switch(items" . ($class ? '-1' : '') . ") {\n";
 
-	my $offset = scalar @args; # which is the first optional?
-	my $total = $offset + scalar @opts;
-	for (my $i=$offset; $i<$total; $i++) {
-	    push @CODE, "case " . ($i+1) . ":\n";
-	    my @tmp;
-	    for (my $j=$offset; $j<=$i; $j++) {
-		my $targ = $opts[$j-$offset]{name};
-		my $type = $opts[$j-$offset]{type};
-		my $src  = "ST($j)";
-		my $conv = $o->typeconv($targ,$src,$type,'input_expr');
-		push @CODE, $conv . ";\n";
-		push @tmp, $targ;
-	    }
-	    push @CODE, "\tRETVAL = " unless $void;
-	    push @CODE, call_or_instantiate(
-		$name, $ctor, $dtor, $class, $thing->{rconst},
-		$thing->{rtype}, (map { $_->{name} } @args), @tmp
-	    );
-	    push @CODE, "\tbreak; /* case " . ($i+1) . " */\n";
-	}
-	push @CODE, "default:\n";
-	push @CODE, "\tRETVAL = " unless $void;
-	push @CODE, call_or_instantiate(
-	    $name, $ctor, $dtor, $class, $thing->{rconst}, $thing->{rtype},
-	    map { $_->{name} } @args
-	);
-	push @CODE, "} /* switch(items) */ \n";
+    my $offset = scalar @args; # which is the first optional?
+    my $total = $offset + scalar @opts;
+    for (my $i=$offset; $i<$total; $i++) {
+        push @CODE, "case " . ($i+1) . ":\n";
+        my @tmp;
+        for (my $j=$offset; $j<=$i; $j++) {
+        my $targ = $opts[$j-$offset]{name};
+        my $type = $opts[$j-$offset]{type};
+        my $src  = "ST($j)";
+        my $conv = $o->typeconv($targ,$src,$type,'input_expr');
+        push @CODE, $conv . ";\n";
+        push @tmp, $targ;
+        }
+        push @CODE, "\tRETVAL = " unless $void;
+        push @CODE, call_or_instantiate(
+        $name, $ctor, $dtor, $class, $thing->{rconst},
+        $thing->{rtype}, (map { $_->{name} } @args), @tmp
+        );
+        push @CODE, "\tbreak; /* case " . ($i+1) . " */\n";
+    }
+    push @CODE, "default:\n";
+    push @CODE, "\tRETVAL = " unless $void;
+    push @CODE, call_or_instantiate(
+        $name, $ctor, $dtor, $class, $thing->{rconst}, $thing->{rtype},
+        map { $_->{name} } @args
+    );
+    push @CODE, "} /* switch(items) */ \n";
     }
     elsif ($void) {
-	push @CODE, "\t";
-	push @CODE, call_or_instantiate(
-	    $name, $ctor, $dtor, $class, 0, '', map { $_->{name} } @args
-	);
+    push @CODE, "\t";
+    push @CODE, call_or_instantiate(
+        $name, $ctor, $dtor, $class, 0, '', map { $_->{name} } @args
+    );
     }
     elsif ($ellipsis or $thing->{rconst}) {
-	push @CODE, "\t";
-	push @CODE, "RETVAL = ";
-	push @CODE, call_or_instantiate(
-	    $name, $ctor, $dtor, $class, $thing->{rconst}, $thing->{rtype},
-	    map { $_->{name} } @args
-	);
+    push @CODE, "\t";
+    push @CODE, "RETVAL = ";
+    push @CODE, call_or_instantiate(
+        $name, $ctor, $dtor, $class, $thing->{rconst}, $thing->{rtype},
+        map { $_->{name} } @args
+    );
     }
     if ($void) {
-	push @CODE, <<'END';
+    push @CODE, <<'END';
         if (PL_markstack_ptr != __temp_markstack_ptr) {
           /* truly void, because dXSARGS not invoked */
           PL_markstack_ptr = __temp_markstack_ptr;
@@ -410,7 +422,7 @@ sub wrap {
 END
     }
     elsif ($ellipsis) {
-	push @CODE, "\tPL_markstack_ptr = __temp_markstack_ptr;\n";
+    push @CODE, "\tPL_markstack_ptr = __temp_markstack_ptr;\n";
     }
 
     # The actual function:
@@ -497,30 +509,30 @@ sub check_type {
 
     # strip "useless" modifiers so the type is found in typemap:
     BADTYPE: while (1) {
-	if (!($ctor || $dtor)) {
-	    my $t = $thing->{rtype};
-	    $t =~ s/^(\s|const|virtual|static)+//g;
-	    if ($t ne 'void' && !$o->typeconv('', '', $t, 'output_expr')) {
-		$badtype = $t;
-		last BADTYPE;
-	    }
-	}
-	foreach (map { $_->{type} } @{$thing->{args}}) {
-	    s/^(const|\s)+//go;
-	    if ($_ ne '...' && !$o->typeconv('', '', $_, 'input_expr')) {
-		$badtype = $_;
-		last BADTYPE;
-	    }
-	}
-	return 1;
+    if (!($ctor || $dtor)) {
+        my $t = $thing->{rtype};
+        $t =~ s/^(\s|const|virtual|static)+//g;
+        if ($t ne 'void' && !$o->typeconv('', '', $t, 'output_expr')) {
+        $badtype = $t;
+        last BADTYPE;
+        }
+    }
+    foreach (map { $_->{type} } @{$thing->{args}}) {
+        s/^(const|\s)+//go;
+        if ($_ ne '...' && !$o->typeconv('', '', $_, 'input_expr')) {
+        $badtype = $_;
+        last BADTYPE;
+        }
+    }
+    return 1;
     }
     # I don't really like this verbosity. This is what 'info' is for. Maybe we
     # should ask Brian for an Inline=DEBUG option.
     warn (
-	"No typemap for type $badtype. " .
-	"Skipping $thing->{rtype} $thing->{name}(" .
-	join(', ', map { $_->{type} } @{$thing->{args}}) .
-	")\n"
+    "No typemap for type $badtype. " .
+    "Skipping $thing->{rtype} $thing->{name}(" .
+    join(', ', map { $_->{type} } @{$thing->{args}}) .
+    ")\n"
     ) if 0;
     return 0;
 }
@@ -537,12 +549,12 @@ sub make_enum {
 END
     my $val = 0;
     foreach (@$body) {
-	my ($k, $v) = @$_;
-	$val = $v if defined $v;
-	push @enum, <<END;
+    my ($k, $v) = @$_;
+    $val = $v if defined $v;
+    push @enum, <<END;
 \tnewCONSTSUB(pkg, \"$k\", newSViv($val));
 END
-	++$val;
+    ++$val;
     }
     push @enum, <<END;
 \t}
